.. Django Act As Auth documentation master file, created by
   sphinx-quickstart on Thu Mar 10 09:22:19 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Django Act As Auth's documentation!
==============================================

.. include:: ../README.rst
   :start-after: .. sales pitch start
   :end-before: .. sales pitch end

----

Contents:

.. toctree::
   :maxdepth: 2

   quickstart
   extension-points
   supported-versions
   license
   release-notes
   contributing
   authors


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

